#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#                  projet Estime, INRIA-Rocquencourt                  #
#                                                                     #
#  Copyright 2005-2011 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: configure.profile,v 1.16.2.1 2011-09-20 14:34:52 fclement Exp $

# User configuration profile.
#
# This profile is sourced by the user configuration script ``configure_user''
# in the root directory of the Pph project.
# It assumes that the variable PROJECT_ROOT_DIR is set to an absolute path.

# Load user Pph system directory names.
. "$PROJECT_ROOT_DIR"/pph/user/scripts/Pph_dirs.profile

# Load user basic commands.
. "$PPH_USER_SCRIPTS_DIR"/basic_commands.profile

# Load user error codes.
. "$PPH_USER_SCRIPTS_DIR"/error_codes.profile

# Load user script functions.
. "$PPH_USER_SCRIPTS_DIR"/script_functions.profile

# Load user intrinsic defaults.
. "$PPH_USER_SCRIPTS_DIR"/intrinsic_defaults.profile

# Load the ID card of the Pph project.
. "$PROJECT_CONFIG_DIR"/Project.profile
if ! $PROJECT_REQUIRE_OCAML_BYT_COMPILER; then
   if ! $PROJECT_REQUIRE_OCAML_BIN_COMPILER; then
       PROJECT_REQUIRE_OCAML_COMMANDS=false
   fi
fi

# Load user configuration usage.
. "$PPH_USER_SCRIPTS_DIR"/configure_usage.profile

# Load user configuration parsing.
. "$PPH_USER_SCRIPTS_DIR"/configure_parsing.profile

report_message "Profile launched"

#
# Build and install the Pph core pervasive tools.
#
$MKDIR "$PPH_BIN_DIR"
install_pph_pervasive_tools "$PPH_CORE_PERVASIVE_TOOLS"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Create the ``.Project_path'' file in the root directory of the Pph project.
#
report_message "Creating the project path in the root directory"
create_path_file "." "$PROJECT_PATH_FILE"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Create the ``.Project_path'' file in the source directory of the Pph user
# pervasive tools.
#
report_message "Creating the project path in the source directory of Pph user\
    pervasives tools"
if test -n "$PPH_USER_PERVASIVE_TOOLS"; then
    for TOOL in $PPH_USER_PERVASIVE_TOOLS; do
        TOOL_RELATIVE_PATH="./pph/$TOOL"
        if test -d "$TOOL_RELATIVE_PATH"; then
            create_path_file "$TOOL_RELATIVE_PATH" "$PROJECT_PATH_FILE"
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
        fi
    done
fi

#
# Create the user Pph preamble ``.User_preamble.pph'' in the root directory of
# the Pph project.
#
report_message "Creating user preamble"
create_user_preamble "$USER_PREAMBLE_FILE" "$PROJECT_PATH_FILE"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Install the configuration script ``config/Compilers.profile''
# and the related configuration makefile ``config/Compilers.pph''.
#

RAD="Compilers"
report_message "Installing $RAD"

# Set the command search path.
COMMAND_SEARCH_PATH=`get_command_search_path`

# Loading project configuration file, if it exists.
COMPILERS_CONFIG_DIR="$PROJECT_CONFIG_DIR"
COMPILERS_CONFIG_BASENAME="$RAD"
COMPILERS_CONFIG_NO_EXTENSION="$COMPILERS_CONFIG_DIR/$COMPILERS_CONFIG_BASENAME"
COMPILERS_CONFIG_SHELL="${COMPILERS_CONFIG_NO_EXTENSION}.profile"
if test -s "$COMPILERS_CONFIG_SHELL"; then
    . $COMPILERS_CONFIG_SHELL
fi

# For each, if required, take first the intrinsic default, then the value
# from the configuration file, and finally, the one from the command line.
if $PROJECT_REQUIRE_C_PREPROCESSOR; then
    C_PREPROCESSORS="$C_PREPROCESSOR_INTRINSIC_DEFAULT_LIST"
    if test "$C_PREPROCESSOR" != "$FALSE"; then
        C_PREPROCESSORS=`$BASENAME $C_PREPROCESSOR`
    fi
    if test -n "$C_PREPROCESSOR_FROM_COMMAND_LINE"; then
        C_PREPROCESSORS="$C_PREPROCESSOR_FROM_COMMAND_LINE"
    fi
    C_PREPROCESSOR=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$C_PREPROCESSORS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi
if $PROJECT_REQUIRE_C_COMPILER; then
    C_COMPILERS="$C_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$C_COMPILER" != "$FALSE"; then
        C_COMPILERS=`$BASENAME $C_COMPILER`
    fi
    if test -n "$C_COMPILER_FROM_COMMAND_LINE"; then
        C_COMPILERS="$C_COMPILER_FROM_COMMAND_LINE"
    fi
    C_COMPILER=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$C_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    case $C_COMPILER in
    ( */cc )
        C_FLAGS_COMPILER_SPECIFIC="$CC_FLAGS_COMPILER_SPECIFIC"
        C_FLAGS_ALL_WARNINGS="$CC_FLAGS_ALL_WARNINGS"
        C_FLAGS_WARN_ERROR="$CC_FLAGS_WARN_ERROR"
        ;;
    ( */gcc )
        C_FLAGS_COMPILER_SPECIFIC="$GCC_FLAGS_COMPILER_SPECIFIC"
	case `$C_COMPILER --version` in
	( *3.3.6* ) C_FLAGS_ALL_WARNINGS="$GCC_FLAGS_ALL_WARNINGS_GCC336";;
        ( * ) C_FLAGS_ALL_WARNINGS="$GCC_FLAGS_ALL_WARNINGS";;
	esac
        C_FLAGS_WARN_ERROR="$GCC_FLAGS_WARN_ERROR"
        ;;
    ( */icc )
        C_FLAGS_COMPILER_SPECIFIC="$ICC_FLAGS_COMPILER_SPECIFIC"
        C_FLAGS_ALL_WARNINGS="$ICC_FLAGS_ALL_WARNINGS"
        C_FLAGS_WARN_ERROR="$ICC_FLAGS_WARN_ERROR"
        ;;
    esac
fi
if $PROJECT_REQUIRE_CPP_PREPROCESSOR; then
    CPP_PREPROCESSORS="$CPP_PREPROCESSOR_INTRINSIC_DEFAULT_LIST"
    if test "$CPP_PREPROCESSOR" != "$FALSE"; then
        CPP_PREPROCESSORS=`$BASENAME $CPP_PREPROCESSOR`
    fi
    if test -n "$CPP_PREPROCESSOR_FROM_COMMAND_LINE"; then
        CPP_PREPROCESSORS="$CPP_PREPROCESSOR_FROM_COMMAND_LINE"
    fi
    CPP_PREPROCESSOR=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$CPP_PREPROCESSORS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi
if $PROJECT_REQUIRE_CPP_COMPILER; then
    CPP_COMPILERS="$CPP_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$CPP_COMPILER" != "$FALSE"; then
        CPP_COMPILERS=`$BASENAME $CPP_COMPILER`
    fi
    if test -n "$CPP_COMPILER_FROM_COMMAND_LINE"; then
        CPP_COMPILERS="$CPP_COMPILER_FROM_COMMAND_LINE"
    fi
    CPP_COMPILER=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$CPP_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    case $CPP_COMPILER in
    ( */g++ )
        CPP_FLAGS_COMPILER_SPECIFIC="$GPP_FLAGS_COMPILER_SPECIFIC"
        CPP_FLAGS_ALL_WARNINGS="$GPP_FLAGS_ALL_WARNINGS"
        CPP_FLAGS_WARN_ERROR="$GPP_FLAGS_WARN_ERROR"
        ;;
    ( */icpc )
        CPP_FLAGS_COMPILER_SPECIFIC="$ICPC_FLAGS_COMPILER_SPECIFIC"
        CPP_FLAGS_ALL_WARNINGS="$ICPC_FLAGS_ALL_WARNINGS"
        CPP_FLAGS_WARN_ERROR="$ICPC_FLAGS_WARN_ERROR"
        ;;
    esac
fi
if $PROJECT_REQUIRE_FORTRAN_PREPROCESSOR; then
    FORTRAN_PREPROCESSORS="$FORTRAN_PREPROCESSOR_INTRINSIC_DEFAULT_LIST"
    if test "$FORTRAN_PREPROCESSOR" != "$FALSE"; then
        FORTRAN_PREPROCESSORS=`$BASENAME $FORTRAN_PREPROCESSOR`
    fi
    if test -n "$FORTRAN_PREPROCESSOR_FROM_COMMAND_LINE"; then
        FORTRAN_PREPROCESSORS="$FORTRAN_PREPROCESSOR_FROM_COMMAND_LINE"
    fi
    FORTRAN_PREPROCESSOR=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$FORTRAN_PREPROCESSORS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi
if $PROJECT_REQUIRE_FORTRAN_COMPILER; then
    FORTRAN_COMPILERS="$FORTRAN_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$FORTRAN_COMPILER" != "$FALSE"; then
        FORTRAN_COMPILERS=`$BASENAME $FORTRAN_COMPILER`
    fi
    if test -n "$FORTRAN_COMPILER_FROM_COMMAND_LINE"; then
        FORTRAN_COMPILERS="$FORTRAN_COMPILER_FROM_COMMAND_LINE"
    fi
    FORTRAN_COMPILER=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$FORTRAN_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    case $FORTRAN_COMPILER in
    ( */gfortran | */g95 )
        FORTRAN_FLAGS_COMPILER_SPECIFIC="$GFORTRAN_FLAGS_COMPILER_SPECIFIC"
        FORTRAN_FLAGS_ALL_WARNINGS="$GFORTRAN_FLAGS_ALL_WARNINGS"
        FORTRAN_FLAGS_WARN_ERROR="$GFORTRAN_FLAGS_WARN_ERROR"
        ;;
    ( */g77 )
        FORTRAN_FLAGS_COMPILER_SPECIFIC="$G77_FLAGS_COMPILER_SPECIFIC"
        FORTRAN_FLAGS_ALL_WARNINGS="$G77_FLAGS_ALL_WARNINGS"
        FORTRAN_FLAGS_WARN_ERROR="$G77_FLAGS_WARN_ERROR"
        ;;
    ( */ifort )
        FORTRAN_FLAGS_COMPILER_SPECIFIC="$IFORT_FLAGS_COMPILER_SPECIFIC"
        FORTRAN_FLAGS_ALL_WARNINGS="$IFORT_FLAGS_ALL_WARNINGS"
        FORTRAN_FLAGS_WARN_ERROR="$IFORT_FLAGS_WARN_ERROR"
        ;;
    esac
fi
if $PROJECT_REQUIRE_JAVA_COMPILER; then
    JAVA_COMPILERS="$JAVA_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$JAVA_COMPILER" != "$FALSE"; then
        JAVA_COMPILERS=`$BASENAME $JAVA_COMPILER`
    fi
    if test -n "$JAVA_COMPILER_FROM_COMMAND_LINE"; then
        JAVA_COMPILERS="$JAVA_COMPILER_FROM_COMMAND_LINE"
    fi
    JAVA_COMPILER=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$JAVA_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    case $JAVA_COMPILER in
    ( */gcj )
        JAVA_FLAGS_COMPILER_SPECIFIC="$GCJ_FLAGS_COMPILER_SPECIFIC"
        JAVA_FLAGS_ALL_WARNINGS="$GCJ_FLAGS_ALL_WARNINGS"
        JAVA_FLAGS_WARN_ERROR="$GCJ_FLAGS_WARN_ERROR"
        ;;
    ( */javac )
        JAVA_FLAGS_COMPILER_SPECIFIC="$JAVAC_FLAGS_COMPILER_SPECIFIC"
        JAVA_FLAGS_ALL_WARNINGS="$JAVAC_FLAGS_ALL_WARNINGS"
        JAVA_FLAGS_WARN_ERROR="$JAVAC_FLAGS_WARN_ERROR"
        ;;
    esac
fi
if $PROJECT_REQUIRE_MOCA_COMPILER; then
    MOCA_COMPILERS="$MOCA_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$MOCA_COMPILER" != "$FALSE"; then
        MOCA_COMPILERS=`$BASENAME $MOCA_COMPILER`
    fi
    if test -n "$MOCA_COMPILER_FROM_COMMAND_LINE"; then
        MOCA_COMPILERS="$MOCA_COMPILER_FROM_COMMAND_LINE"
    fi
    MOCA_COMPILER=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$MOCA_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi
if $PROJECT_REQUIRE_OCAML_PREPROCESSOR; then
    OCAML_PREPROCESSORS="$OCAML_PREPROCESSOR_INTRINSIC_DEFAULT_LIST"
    if test "$OCAML_PREPROCESSOR" != "$FALSE"; then
        OCAML_PREPROCESSORS=`$BASENAME $OCAML_PREPROCESSOR`
    fi
    if test -n "$OCAML_PREPROCESSOR_FROM_COMMAND_LINE"; then
        OCAML_PREPROCESSORS="$OCAML_PREPROCESSOR_FROM_COMMAND_LINE"
    fi
    OCAML_PREPROCESSOR=`\
      find_first_command "$COMMAND_SEARCH_PATH" "" "$OCAML_PREPROCESSORS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    case $OCAML_PREPROCESSOR in
    ( */camlp4 )
        OCAML_PP_FLAGS_INTF="$CAMLP4_FLAGS_INTF"
        OCAML_PP_FLAGS_IMPL="$CAMLP4_FLAGS_IMPL"
        ;;
    ( */camlp5 )
        OCAML_PP_FLAGS_INTF="$CAMLP5_FLAGS_INTF"
        OCAML_PP_FLAGS_IMPL="$CAMLP5_FLAGS_IMPL"
        ;;
    esac
fi
if test -z "$OCAML_COMMAND_SEARCH_PATH"; then
    OCAML_COMMAND_SEARCH_PATH="$COMMAND_SEARCH_PATH"
fi
if test -n "$OCAML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE"; then
    OCAML_COMMAND_SEARCH_PATH=`absolute_command_search_path \
                               $OCAML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
fi
OCAML_COMPILATION_TARGETS=""
OCAML_COMPILATION_EXTENSIONS=""
if $PROJECT_REQUIRE_OCAML_BYT_COMPILER; then
    OCAML_BYT_COMPILERS="$OCAML_BYT_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$OCAML_BYT_COMPILER" != "$FALSE"; then
        OCAML_BYT_COMPILERS=`$BASENAME $OCAML_BYT_COMPILER`
    fi
    if test -n "$OCAML_BYT_COMPILER_FROM_COMMAND_LINE"; then
        OCAML_BYT_COMPILERS="$OCAML_BYT_COMPILER_FROM_COMMAND_LINE"
    fi
    OCAML_BYT_COMPILER=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" \
                         "$OCAML_BYT_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    OCAML_COMMAND_SEARCH_PATH=`\
      $ECHO $OCAML_BYT_COMPILER | \
      $SED -e "s/\.opt\$//;s%/$OCAML_BYT_COMPILER_INTRINSIC_DEFAULT_LIST\$%%"`
    OCAML_COMPILATION_TARGETS="$OCAML_COMPILATION_TARGETS byt"
    OCAML_COMPILATION_EXTENSIONS="$OCAML_COMPILATION_EXTENSIONS .byt"
fi
if $PROJECT_REQUIRE_OCAML_BIN_COMPILER; then
    OCAML_BIN_COMPILERS="$OCAML_BIN_COMPILER_INTRINSIC_DEFAULT_LIST"
    if test "$OCAML_BIN_COMPILER" != "$FALSE"; then
        OCAML_BIN_COMPILERS=`$BASENAME $OCAML_BIN_COMPILER`
    fi
    if test -n "$OCAML_BIN_COMPILER_FROM_COMMAND_LINE"; then
        OCAML_BIN_COMPILERS="$OCAML_BIN_COMPILER_FROM_COMMAND_LINE"
    fi
    OCAML_BIN_COMPILER=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" \
                         "$OCAML_BIN_COMPILERS"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
    OCAML_COMMAND_SEARCH_PATH=`\
      $ECHO $OCAML_BIN_COMPILER | \
      $SED -e "s/\.opt\$//;s%/$OCAML_BIN_COMPILER_INTRINSIC_DEFAULT_LIST\$%%"`
    OCAML_COMPILATION_TARGETS="$OCAML_COMPILATION_TARGETS bin"
    OCAML_COMPILATION_EXTENSIONS="$OCAML_COMPILATION_EXTENSIONS .bin"
fi
if $PROJECT_REQUIRE_OCAML_COMMANDS; then
    OCAML_DEP_GENERATOR=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamldep"` && \
    OCAML_DOC_GENERATOR=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamldoc"` && \
    OCAML_TOP_GENERATOR=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamlmktop"` && \
    OCAML_LIBRARIAN=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamlmklib"` && \
    OCAML_LEX_GENERATOR=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamllex"` && \
    OCAML_YAC_GENERATOR=`\
      find_first_command "$OCAML_COMMAND_SEARCH_PATH" ".opt" "ocamlyacc"`
    IER=$?
    if test $IER -ne 0; then exit $IER; fi

fi

fill_config_file \
    "$COMPILERS_CONFIG_DIR" "$COMPILERS_CONFIG_BASENAME" \
    "C preprocessor" "C_PREPROCESSOR" "$C_PREPROCESSOR" \
    "C compiler" "C_COMPILER" "$C_COMPILER" \
    "C compiler specific option" \
      "    C_FLAGS_COMPILER_SPECIFIC" "$C_FLAGS_COMPILER_SPECIFIC" \
    "C all-warnings option" \
      "    C_FLAGS_ALL_WARNINGS" "$C_FLAGS_ALL_WARNINGS" \
    "C warnings-are-errors option" \
      "    C_FLAGS_WARN_ERROR" "$C_FLAGS_WARN_ERROR" \
    "C++ preprocessor" "CPP_PREPROCESSOR" "$CPP_PREPROCESSOR" \
    "C++ compiler" "CPP_COMPILER" "$CPP_COMPILER" \
    "C++ compiler specific option" \
      "    CPP_FLAGS_COMPILER_SPECIFIC" "$CPP_FLAGS_COMPILER_SPECIFIC" \
    "C++ all-warnings option" \
      "    CPP_FLAGS_ALL_WARNINGS" "$CPP_FLAGS_ALL_WARNINGS" \
    "C++ warnings-are-errors option" \
      "    CPP_FLAGS_WARN_ERROR" "$CPP_FLAGS_WARN_ERROR" \
    "Fortran preprocessor" "FORTRAN_PREPROCESSOR" "$FORTRAN_PREPROCESSOR" \
    "Fortran compiler" "FORTRAN_COMPILER" "$FORTRAN_COMPILER" \
    "Fortran compiler specific option" \
      "    FORTRAN_FLAGS_COMPILER_SPECIFIC" "$FORTRAN_FLAGS_COMPILER_SPECIFIC" \
    "Fortran all-warnings option" \
      "    FORTRAN_FLAGS_ALL_WARNINGS" "$FORTRAN_FLAGS_ALL_WARNINGS" \
    "Fortran warnings-are-errors option" \
      "    FORTRAN_FLAGS_WARN_ERROR" "$FORTRAN_FLAGS_WARN_ERROR" \
    "Java compiler" "JAVA_COMPILER" "$JAVA_COMPILER" \
    "Java compiler specific option" \
      "    JAVA_FLAGS_COMPILER_SPECIFIC" "$JAVA_FLAGS_COMPILER_SPECIFIC" \
    "Java all-warnings option" \
      "    JAVA_FLAGS_ALL_WARNINGS" "$JAVA_FLAGS_ALL_WARNINGS" \
    "Java warnings-are-errors option" \
      "    JAVA_FLAGS_WARN_ERROR" "$JAVA_FLAGS_WARN_ERROR" \
    "Moca compiler" "MOCA_COMPILER" "$MOCA_COMPILER" \
    "OCaml preprocessor" "OCAML_PREPROCESSOR" "$OCAML_PREPROCESSOR" \
    "OCaml preprocessor interface options" \
      "    OCAML_PP_FLAGS_INTF" "$OCAML_PP_FLAGS_INTF" \
    "OCaml preprocessor implementation options" \
      "    OCAML_PP_FLAGS_IMPL" "$OCAML_PP_FLAGS_IMPL" \
    "OCaml command search path" \
      "OCAML_COMMAND_SEARCH_PATH" "$OCAML_COMMAND_SEARCH_PATH" \
    "OCaml byte compiler" "OCAML_BYT_COMPILER" "$OCAML_BYT_COMPILER" \
    "OCaml native compiler" "OCAML_BIN_COMPILER" "$OCAML_BIN_COMPILER" \
    "OCaml compilation targets" \
      "    OCAML_COMPILATION_TARGETS" "$OCAML_COMPILATION_TARGETS" \
    "OCaml compilation extensions" \
      "    OCAML_COMPILATION_EXTENSIONS" "$OCAML_COMPILATION_EXTENSIONS" \
    "OCaml dependencies generator" \
      "OCAML_DEP_GENERATOR" "$OCAML_DEP_GENERATOR" \
    "OCaml documentation generator" \
      "OCAML_DOC_GENERATOR" "$OCAML_DOC_GENERATOR" \
    "OCaml top-level generator" "OCAML_TOP_GENERATOR" "$OCAML_TOP_GENERATOR" \
    "OCaml librarian" "OCAML_LIBRARIAN" "$OCAML_LIBRARIAN" \
    "OCaml lexer generator" "OCAML_LEX_GENERATOR" "$OCAML_LEX_GENERATOR" \
    "OCaml parser generator" "OCAML_YAC_GENERATOR" "$OCAML_YAC_GENERATOR"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Install the configuration script
# ``config/Non_standard_ocaml_libraries.profile''
# and the related configuration makefile
# ``config/Non_standard_ocaml_libraries.pph''.
#
RAD="Non_standard_ocaml_libraries"
report_message "Installing $RAD"
NON_STANDARD_OCAML_LIB_CONFIG_FILE_BASENAME="$PROJECT_CONFIG_DIR/$RAD"
$TOUCH "$NON_STANDARD_OCAML_LIB_CONFIG_FILE_BASENAME.profile"
$TOUCH "$NON_STANDARD_OCAML_LIB_CONFIG_FILE_BASENAME.pph"
$TOUCH "$NON_STANDARD_OCAML_LIB_CONFIG_FILE_BASENAME.env"
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Install the configuration script ``config/Install_root_dir.profile''
# and the related configuration makefile ``config/Install_root_dir.pph''.
#

RAD="Install_root_dir"
report_message "Installing $RAD"

INSTALL_ROOT_DIR_CONFIG_DIR="$PROJECT_CONFIG_DIR"
INSTALL_ROOT_DIR_CONFIG_BASENAME="$RAD"
INSTALL_ROOT_DIR_CONFIG_NO_EXTENSION="\
$INSTALL_ROOT_DIR_CONFIG_DIR/$INSTALL_ROOT_DIR_CONFIG_BASENAME"

# Perform sanity check: nonempty intrinsic default.
if test -z "$INSTALL_ROOT_DIR_INTRINSIC_DEFAULT"; then
    internal_error "empty default directory name"
    exit $INTERNAL_ERROR
fi

# Set INSTALL_ROOT_DIR_CANDIDATE to the intrinsic default value.
INSTALL_ROOT_DIR_CANDIDATE=`expand "$INSTALL_ROOT_DIR_INTRINSIC_DEFAULT"`

# The default installation root directory from Pph configuration file.
INSTALL_ROOT_DIR_PPH_CONFIG="$PPH_CONFIG_DIR/$RAD.profile"
INSTALL_ROOT_DIR=""
if test -s "$INSTALL_ROOT_DIR_PPH_CONFIG"; then
    . $INSTALL_ROOT_DIR_PPH_CONFIG
fi
if test -n "$INSTALL_ROOT_DIR"; then
   INSTALL_ROOT_DIR_CANDIDATE=`expand "$INSTALL_ROOT_DIR"`
fi

# The default installation root directory from project configuration file.
INSTALL_ROOT_DIR_CONFIG="${INSTALL_ROOT_DIR_CONFIG_NO_EXTENSION}.profile"
INSTALL_ROOT_DIR=""
if test -s "$INSTALL_ROOT_DIR_CONFIG"; then
    . $INSTALL_ROOT_DIR_CONFIG
fi
if test -n "$INSTALL_ROOT_DIR"; then
   INSTALL_ROOT_DIR_CANDIDATE=`expand "$INSTALL_ROOT_DIR"`
fi

# Set INSTALL_ROOT_DIR to the value entered on the command line.
if test -n "$INSTALL_ROOT_DIR_FROM_COMMAND_LINE"; then
  INSTALL_ROOT_DIR_CANDIDATE=`expand "$INSTALL_ROOT_DIR_FROM_COMMAND_LINE"`
fi

# Perform sanity checks.
if test -z "$INSTALL_ROOT_DIR_CANDIDATE"; then
    internal_error "empty directory name"
    exit $INTERNAL_ERROR
elif test ! -d "$INSTALL_ROOT_DIR_CANDIDATE"; then
    error "$INSTALL_ROOT_DIR_CANDIDATE: no such directory"
    exit $INVALID_VALUE_ERROR
fi
HERE=`absolute_directory_path "."`
if test "$INSTALL_ROOT_DIR_CANDIDATE" = "$HERE"; then
    error "cannot install in the source directory"
    exit $INVALID_VALUE_ERROR
fi

INSTALL_ROOT_DIR=`absolute_directory_path "$INSTALL_ROOT_DIR_CANDIDATE"`

# Remember the current value of $INSTALL_ROOT_DIR.
# Do not forget to exit on errors.
fill_config_file \
    "$INSTALL_ROOT_DIR_CONFIG_DIR" "$INSTALL_ROOT_DIR_CONFIG_BASENAME" \
    "Installation root directory" "INSTALL_ROOT_DIR" "$INSTALL_ROOT_DIR"
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Echo all the configure settings.
$CAT << eof >&2

Configuration settings for project $PROJECT_NAME.

`$EGREP -v '^#|^$' "$PROJECT_CONFIG_DIR"/Compilers.pph`
`$EGREP -v '^#|^$' "$PROJECT_CONFIG_DIR"/Non_standard_ocaml_libraries.pph`
`$EGREP -v '^#|^$' "$PROJECT_CONFIG_DIR"/Install_root_dir.pph`

eof

#
# Remaining user configuration phase using makefiles.
# This is for the propagation of the preambles.
# Do not forget to exit on errors.
#

report_message "Launching user's configuration makefile"
$MAKE_COMMAND VERBOSITY_LEVEL=$VERBOSITY_LEVEL configure \
  > $MAKE_CONFIGURE_LOG_FILE_NAME
IER=$?
if test $IER -ne 0; then exit $IER; fi

#
# Build and install the Pph user pervasive tools.
# This could be done using makefiles, but it seems more convenient to use
# the same script function than for the core pervasive tools (in particular,
# using makefiles, it would be a non recursive task).
#
$MKDIR "$PPH_BIN_DIR"
install_pph_pervasive_tools "$PPH_USER_PERVASIVE_TOOLS"
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Memorize the configure options.
if test -n "$CONFIGURE_OPTIONS"; then
    $ECHO $CONFIGURE_OPTIONS \
        > "$PROJECT_CONFIG_DIR"/$CONFIGURE_OPTIONS_FILE_NAME
else
#   Keep an eventually already existing file.
    $TOUCH "$PROJECT_CONFIG_DIR"/$CONFIGURE_OPTIONS_FILE_NAME
fi
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Configure checkpoint.
$TOUCH "$PROJECT_CONFIG_DIR"/$CONFIGURE_CHECKPOINT
IER=$?
if test $IER -ne 0; then exit $IER; fi

report_message "Profile done"
