CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C                  projet Estime, INRIA-Rocquencourt                  C
C                                                                     C
C  Copyright 2004-2011 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: print_communication.F,v 1.4 2011-03-09 12:50:16 fclement Exp $

C     
C     Routines to print a communication on an output channel.
C     
C     The communication is supposed to have been already stored into the
C     memory for outgoing communications (memory(PIO_OUT)).
C     The memory mapping has also been written into
C     memory_mapping(PIO_OUT).
C     
C     The printing process is in charge to read the communication from
C     the memory(PIO_OUT) according to the memory_mapping(PIO_OUT) and
C     to print it into the output channel.
C     
      
#include "pio_constants.h"
      
      subroutine print_typed_values(oc, n)
C     Print several typed values.
      
      implicit none
      
C     Input arguments.
      integer oc, n
      
C     Local variable.
      integer i
   
C     External function.
      logical pio_get_debug_mode
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In print_typed_values, n = ', n
      endif
      
      do i = 1, n
         if (pio_get_debug_mode()) then
            write(PIO_DEBUG, *) 'In print_typed_values, i = ', i
         endif
         call print_typed_value(oc, i)
      enddo
      
      return
      end
      
      
      character function format_of_communication_type(typ)
C     Mapping from communication type to format.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*28
      character fmt
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'format_of_communication_type'
      
      if (typ .eq. PIO_PHRASE) then
         fmt(1:1) = 'p'
      else if (typ .eq. PIO_TASK) then
         fmt = 't'
      else if (typ .eq. PIO_RESULT) then
         fmt = 'r'
      else if (typ .eq. PIO_ERROR) then
         fmt = 'e'
      else if (typ .eq. PIO_SERVICE) then
         fmt = 's'
      else
         call error_wrong_communication_type(sbr, typ)
      endif
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'fmt = |', fmt, '|'
      endif
      
      format_of_communication_type = fmt
      
      return
      end
      
      
      subroutine print_communication_type(typ)
C     Print communication type.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*24, fmt
      
C     External function.
      character format_of_communication_type
      
      sbr = 'print_communication_type'
      
      fmt = format_of_communication_type(typ)
      
      call buffer_print_char(sbr, '%')
      call buffer_print_char(sbr, fmt)
      
      return
      end
      
      
      subroutine print_communication_values_number(n)
C     Print a Values_Number in the sense of the I/O library.
      
      implicit none
      
C     Input argument.
      integer n
      
C     Local variable.
      character sbr*33
      
      sbr = 'print_communication_values_number'
      
      call buffer_print_size(sbr, n)
      
      return
      end
      
      
      subroutine print_phrase_body(oc, typ, n)
C     Print the body of a phrase communication.
      
      implicit none
      
C     Input arguments.
      integer oc, typ, n
      
C     Local variable.
      character sbr*17
      
      sbr = 'print_phrase_body'
      
      call print_communication_type(typ)
      call buffer_print_space(sbr)
      call print_communication_values_number(n)
      call buffer_print_newline(sbr)
      
      call print_typed_values(oc, n)
      
      return
      end
      
      
      subroutine print_communication_name
C     Print the name of a task or service communication.
      
      implicit none
      
C     Local variables.
      character sbr*24, name*PIO_MAX_IDENT_LENGTH
      integer nlen
      
      sbr = 'print_communication_name'
      
      nlen = PIO_MAX_IDENT_LENGTH
      call fetch_communication_name(sbr, PIO_OUT, name, nlen)
      call buffer_print_delimited_string(sbr, name, nlen)
      
      return
      end
      
      
      subroutine print_task_body(oc, typ, n)
C     Print the body of a task communication.
      
      implicit none
      
C     Input arguments.
      integer oc, typ, n
      
C     Local variable.
      character sbr*15
      
      sbr = 'print_task_body'
      
      call print_communication_type(typ)
      call buffer_print_space(sbr)
      call print_communication_values_number(n)
      call buffer_print_space(sbr)
      call print_communication_name
      call buffer_print_newline(sbr)
      
      call print_typed_values(oc, n)
      
      return
      end
      
      
      subroutine print_result_body(oc, typ, n)
C     Print the body of a result communication.
      
      implicit none
      
C     Input arguments.
      integer oc, typ, n
      
C     Local variable.
      character sbr*17
      
      sbr = 'print_result_body'
      
      call print_communication_type(typ)
      call buffer_print_space(sbr)
      call print_communication_values_number(n)
      call buffer_print_newline(sbr)
      
      call print_typed_values(oc, n)
      
      return
      end
      
      
      subroutine print_error_body(oc, typ, n)
C     Print the body of an error communication.
      
      implicit none
      
C     Input arguments.
      integer oc, typ, n
      
C     Local variable.
      character sbr*16
      
      sbr = 'print_error_body'
      
      call print_communication_type(typ)
      call buffer_print_space(sbr)
      call print_communication_values_number(n)
      call buffer_print_newline(sbr)
      
      call print_typed_values(oc, n)
      
      return
      end
      
      
      subroutine print_service_body(oc, typ, n)
C     Print the body of a service communication.
      
      implicit none
      
C     Input arguments.
      integer oc, typ, n
      
C     Local variable.
      character sbr*18
      
      sbr = 'print_service_body'
      
      call print_communication_type(typ)
      call buffer_print_space(sbr)
      call print_communication_values_number(n)
      call buffer_print_space(sbr)
      call print_communication_name
      call buffer_print_newline(sbr)

      call print_typed_values(oc, n)
      
      return
      end
      
      
      subroutine print_communication_body(oc)
C     Print communication body.
      
      implicit none
      
C     Input argument.
      integer oc
      
C     Local variables.
      character sbr*24
      integer typ, n
      
C     External functions.
      integer fetch_communication_type
      integer fetch_communication_values_number
      
      sbr = 'print_communication_body'
      
      typ = fetch_communication_type(sbr, PIO_OUT)
      n = fetch_communication_values_number(sbr, PIO_OUT)

      if (typ .eq. PIO_PHRASE) then
         call print_phrase_body(oc, typ, n)
      else if (typ .eq. PIO_TASK) then
         call print_task_body(oc, typ, n)
      else if (typ .eq. PIO_RESULT) then
         call print_result_body(oc, typ, n)
      else if (typ .eq. PIO_ERROR) then
         call print_error_body(oc, typ, n)
      else if (typ .eq. PIO_SERVICE) then
         call print_service_body(oc, typ, n)
      endif
      
      return
      end
      
      
      subroutine print_communication(oc)
C     Print communicaton on output channel oc.
      
      implicit none
      
C     Input argument.
      integer oc
      
C     Local variable.
      character sbr*19
      
C     External functions.
      logical pio_get_debug_mode
      
      sbr = 'print_communication'
      
      call check_memory_clean(sbr, PIO_OUT, .True.)
      call check_memory_mapping_clean(sbr, PIO_OUT, .True.)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'Communication print on channel ', oc,
     +        ' started.'
      endif
      
      call init_buffer(sbr, PIO_OUT)
      
      call buffer_print_char(sbr, '(')
      call buffer_print_newline(sbr)
      call print_communication_body(oc)
      call buffer_print_char(sbr, ')')
      call buffer_print_newline(sbr)
C      call buffer_print_newline(sbr)
C     We omit previous call to buffer_print_newline since we must flush
C     the  buffer (in order to keep it small enough), and flush_buffer
C     adds an end_of_line marker (because we use a formatted write to
C     flush the buffer).
      call flush_buffer(sbr, oc)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'Communication print on channel ', oc,
     +        ' completed.'
      endif
      
      return
      end
